{
----------------------------------------------------------
MAS-CompMaker was used to generate this code
MAS-CompMaker, copyright(c) 2000, Mats Asplund / MAs Prod.
----------------------------------------------------------

Component Name: TExecApp
        Author: Mats Asplund
      Creation: 2000-08-30
       Version: 1.0
   Description: A speedbutton-component used to launch applications.
        Credit:
        E-mail: mats.asplund@telia.com
          Site: http://w1.545.telia.com/~u54503556/delphi/mdp.htm
  Legal issues: Copyright (C) 2000 by Mats Asplund


         Usage: This software is provided 'as-is', without any express or
                implied warranty.  In no event will the author be held liable
                for any  damages arising from the use of this software.

                Permission is granted to anyone to use this software for any
                purpose, including commercial applications, and to alter it
                and redistribute it freely, subject to the following
                restrictions:

                1. The origin of this software must not be misrepresented,
                   you must not claim that you wrote the original software.
                   If you use this software in a product, an acknowledgment
                   in the product documentation would be appreciated but is
                   not required.

                2. Altered source versions must be plainly marked as such, and
                   must not be misrepresented as being the original software.

                3. This notice may not be removed or altered from any source
                   distribution.

                4. If you decide to use this software in any of your applications.
                   Send me an EMail address and tell me about it.

Quick Reference:
                TExecApp inherits from TImage.

                Key-Properties:
                  FileName: The path and name of the file to launch.

                Key-Events:

                Key-Methods:
                  Click-method overriden.
--------------------------------------------------------------------------------
}
unit ExecApp;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, ExtCtrls, DsgnIntf, ShellAPI, Buttons;

type

  EExecApp = class(Exception);

  TFileNameProperty = class(TStringProperty)
  public
    function GetAttributes: TPropertyAttributes; override;
    procedure Edit; override;
  end;

  TExecApp = class(TSpeedButton)
  private
    FCopyright: string;
    FFileName: TFileName;
    ErrorCode: integer;
    procedure SetCop(Value: string);
    procedure SetFileName(Value: TFileName);
    function GetErrorString: string;
  { Private declarations }
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure Click; override;
  { Private declarations }
  published
    property FileName: TFileName read FFileName write SetFileName;
    property Copyright: string read FCopyright write SetCop;
  { Published declarations }
  end;


procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('MAs Prod.', [TExecApp]);
  RegisterPropertyEditor(TypeInfo(TFileName), nil, '', TFileNameProperty);
end;

function TFileNameProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog]
end {GetAttributes};

procedure TFileNameProperty.Edit;
begin
  with TOpenDialog.Create(Application) do
  try
    Title := GetName; { name of property as OpenDialog caption }
    FileName := GetValue;
    Filter := 'All Files (*.*)|*.*';
    HelpContext := 0;
    Options := Options + [ofShowHelp, ofPathMustExist, ofFileMustExist];
    if Execute then SetValue(FileName);
  finally
    Free
  end;
end;

procedure TExecApp.Click;
begin
  inherited;
  if ShellExecute(0, 'open', PChar(FFileName), '', '', SW_SHOWNORMAL) < 33 then
  begin
    ErrorCode := GetLastError();
    raise EExecApp.Create(GetErrorString);
  end;
end;

constructor TExecApp.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FCopyright := 'Copyright (c) 2000, MAs Prod. / Mats Asplund';
end;

destructor TExecApp.Destroy;
begin
  inherited Destroy;
end;

function TExecApp.GetErrorString: string;
begin
  case ErrorCode of
     0: Result := 'System was out of memory, executable file was corrupt, or relocations were invalid';
     2: Result := 'File was not found';
     3: Result := 'Path was not found';
     5: Result := 'Attempt was made to dynamically link to a task, or there was a sharing or network-protection error';
     6: Result := 'Library required sepa: Rate data segments for each task';
     8: Result := 'There was insufficient memory to start the application';
    10: Result := 'Windows version was incorrect';
    11: Result := 'Executable file was invalid. Either it was not a Windows application or there was an error in the .EXE image';
    12: Result := 'Application was designed for a different operating system';
    13: Result := 'Application was designed for MS-DOS 4.0';
    14: Result := 'Type of executable file was unknown';
    15: Result := 'Attempt was made to load a real-mode application (developed for an earlier version of Windows)';
    16: Result := 'Attempt to load second instance of an executable containing multiple data segments not marked read-only';
    19: Result := 'Attempt was made to load a compressed executable file. The file must be decompressed before it can be loaded';
    20: Result := 'Dynamic-link library (DLL) file was invalid. One of the DLLs required to run this application was corrupt';
    21: Result := 'Application requires 32-bit extensions';
  end;
end;

procedure TExecApp.SetCop(Value: string);
begin
  Exit;
end;

procedure TExecApp.SetFileName(Value: TFileName);
begin
  FFileName := Value;
end;

end.
